==> haskell-dav-1.3.1-66-i686.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.1
id: DAV-1.3.1-EpTuTGeMPaQ3R8VuiV9qql
key: DAV-1.3.1-EpTuTGeMPaQ3R8VuiV9qql
license: GPL-3
copyright: Copyright (C) 2012-2016  Clint Adams
maintainer: clint@debian.org
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
author: Clint Adams
exposed: True
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
abi: 85769782f62f50a708a7cb1520e4236c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/DAV-1.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/DAV-1.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/DAV-1.3.1
hs-libraries: HSDAV-1.3.1-EpTuTGeMPaQ3R8VuiV9qql
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi containers-0.5.7.1
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    http-client-0.5.6.1-LjnNcxn7EAdDT87PUFggs5
    http-client-tls-0.3.4-1o0NKWASLmNvVHSIvcc3Y
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    lens-4.15.1-AXftRhVcDpjE055oLJWaDH mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    xml-conduit-1.4.0.4-jgjR083EvZEe9eaBRjLEo
    xml-hamlet-0.4.1-IUrDDTcqhHULpz0hicXSPR
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dav-1.3.1-67-i686.pkg.tar.xz: usr/share/haskell/register/haskell-dav.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: DAV
version: 1.3.1
id: DAV-1.3.1-HTcyUD3irqI7SHscIVyb4C
key: DAV-1.3.1-HTcyUD3irqI7SHscIVyb4C
license: GPL-3
copyright: Copyright (C) 2012-2016  Clint Adams
maintainer: clint@debian.org
homepage: http://floss.scru.org/hDAV
synopsis: RFC 4918 WebDAV support
description:
    This is a library for the Web Distributed Authoring and Versioning
    (WebDAV) extensions to HTTP.  At present it supports a very small
    subset of client functionality.
    .
    In addition, there is an executable, hdav, which can be used for
    command-line operation.
category: Web
author: Clint Adams
exposed: True
exposed-modules:
    Network.Protocol.HTTP.DAV
hidden-modules: Network.Protocol.HTTP.DAV.TH
abi: f73c4915c074e1daae3a4fba112fa2d4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/DAV-1.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/DAV-1.3.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/DAV-1.3.1
hs-libraries: HSDAV-1.3.1-HTcyUD3irqI7SHscIVyb4C
depends:
    base-4.9.0.0 bytestring-0.10.8.1
    case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi containers-0.5.7.1
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    http-client-0.5.6.1-LjnNcxn7EAdDT87PUFggs5
    http-client-tls-0.3.4-1o0NKWASLmNvVHSIvcc3Y
    http-types-0.9.1-DAWlwwLyGeDDnRhY9ftEgi
    lens-4.15.1-AQi0y6GexOY2BzSazyYQSD mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
    utf8-string-1.0.1.1-2T8mBCuEDlXDo8zed8Onw4
    xml-conduit-1.4.0.4-jgjR083EvZEe9eaBRjLEo
    xml-hamlet-0.4.1-IUrDDTcqhHULpz0hicXSPR
haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
haddock-html: /usr/share/doc/haskell-dav/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
